#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Heritage.py -- Python Interface to The Sanskrit Heritage Platform
"""

__author__ = """Hrishikesh Terdalkar"""
__email__ = "hrishikeshrt@linuxmail.org"
__version__ = "1.1.0"
__created_on__ = "Fri Jan  1 11:18:04 2021"

###############################################################################

from .heritage import HeritagePlatform, HeritageOutput  # noqa
from .constants import HERITAGE_LANG, HERITAGE_COLOURS  # noqa
from .models import (  # noqa
    AnalysisCandidate,
    ConjugationCell,
    ConjugationTable,
    DeclensionTable,
    DictionaryEntry,
    Font,
    Lexicon,
    Method,
    SandhiMode,
    SearchResult,
    SolutionAnalysis,
    WordAnalysis,
    WordRole,
)
